@@ -13,3 +13,6 @@ class Post(models.Model):
 
     def get_absolute_url(self):
         return reverse("posts:detail", kwargs={"pk": self.pk})
+
+    class Meta:
+        ordering = ["pk"]
